@@ -54,11 +54,9 @@ private Q_SLOTS:
   void removeRows_data();
   void removeRows();
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
   void selectionModelModelChange();
   void deselection_data();
   void deselection();
-#endif
 
 private:
   const QStringList days;
@@ -122,7 +120,6 @@ void KSelectionProxyModelTest::selectOnSourceReset()
   QVERIFY(selectionModel.selection().contains(strings.index(2, 0)));
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
 void KSelectionProxyModelTest::selectionModelModelChange()
 {
   QStringListModel strings(days);
@@ -906,8 +903,6 @@ void KSelectionProxyModelTest::removeRows()
     QCOMPARE(proxy.rowCount(), expectedRowCountAfter);
 }
 
-#endif
-
 void KSelectionProxyModelTest::selectionMapping()
 {
     QStringListModel strings(days);
